package com.flyer.foster.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.AreaAddDTO;
import com.flyer.foster.dto.AreaQueryDTO;
import com.flyer.foster.dto.AreaUpdateDTO;
import com.flyer.foster.service.IAreaService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 区域
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/area")
public class AreaController {
    @Autowired
    private IAreaService iAreaService;

    /**
     * 区域列表-分页
     *
     * @param current 当前页，默认1
     * @param size    当前页显示条数，默认10
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, AreaQueryDTO queryDTO) {
        return R.ok().result(iAreaService.getPageList(new Page<>(current, size), queryDTO));
    }

    /**
     * 新增区域
     *
     * @param addDTO
     * @return
     */
    @PostMapping("")
    public R addArea(@Valid @RequestBody AreaAddDTO addDTO) {
        return R.ok().result(iAreaService.addArea(addDTO));
    }

    @PutMapping("/{areaId}")
    public R updateArea(@PathVariable Integer areaId,@RequestBody AreaUpdateDTO updateDTO){
        updateDTO.setId(areaId);
        return R.ok().result(iAreaService.updateArea(updateDTO));
    }

    /**
     * 删除区域
     *
     * @return
     */
    @DeleteMapping("/delete")
    public R deleteArea(@RequestBody List<Integer> idList) {
        return R.ok().result(iAreaService.deleteByIdList(idList));
    }
}
